<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Настройки на яркостта</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки на осветеност и яркост:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Осветеност</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Яркост</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Изискване потвърждение след промяна на настройките</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="54"/>
        <source>Currently unsupported under Wayland</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="122"/>
        <source>Brightness settings changed</source>
        <translation>Настройките на яркостта са променени</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="123"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Изисква се потвърждение. Коректни ли са настройките?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Изход:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Increase brightness.</source>
        <translation>Увеличаване на яркостта.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Decrease brightness.</source>
        <translation>Намаляване на яркостта.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Задаване яркост от 1 до 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Reset gamma to default value.</source>
        <translation>Възстановяване на стойностите на Gamma по подразбиране.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="114"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Увеличаване/намаляване и задаване на стойност не могат да бъдат приложени в последователност</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="119"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Опциите за увеличаване и намаляване не могат да бъдат приложени в последователност</translation>
    </message>
</context>
</TS>
